#' Build a fairify website
#'
#' @details
#' In order to create a fairiy website containing fairify reports, this function
#' runs successively:
#'
#' - [devtools::build_readme] if a file README.Rmd exists
#' - [pkgdown::build_site]
#' - [render_reports]
#'
#' @inheritParams pkgdown::build_site
#' @inheritParams render_reports
#' @param ... Further parameters to pass to [render_reports]
#'
#' @return Used for side effects
#' @export
#'
build_site <- function(pkg = pkgload::pkg_path(),
                       examples = TRUE,
                       run_dont_run = FALSE,
                       seed = 1014,
                       lazy = FALSE,
                       override = list(),
                       preview = NA,
                       devel = TRUE,
                       new_process = !devel,
                       install = !devel,
                       reports_dir = file.path(pkg, "reports"),
                       ...) {
  if (file.exists(file.path(pkg, "README.Rmd"))) {
    devtools::build_readme(path = pkg)
  }
  unlink(file.path(pkg, "public"), recursive = TRUE)
  pkgdown::build_site(pkg = pkg,
                      examples  = examples,
                      run_dont_run  = run_dont_run,
                      seed  = seed,
                      lazy  = lazy,
                      override  = override,
                      preview  = preview,
                      devel  = devel,
                      new_process  = new_process,
                      install  = install)
  render_reports(reports_dir = reports_dir, ...)
  invisible(TRUE)
}
